##  Step 3. Add Organizations
Organizations represent the users of Applications and are intended for modeling who is using certain applications. The Organization Fact Sheet type is an essential element to represent your organization’s business architecture in SAP LeanIX, and you can model different dimensions to create hierarchical structures. It allows you to get some basic views to understand synergies and gaps in the application landscape across different parts of the organization.
You can use the following 5 Fact Sheet subtypes for the five major dimensions that SAP LeanIX customers typically capture:
  * Business Unit: Business Units are distinct divisions within a larger organization.
Example: Retail
  * Customer: Customers represent customer groups/segments with similar needs.
Example: Buyer Persona
  * Region: Regions represent geographical divisions within a larger organization and/or business unit.
Example: Europe, Europe / France
  * Legal Entity: Legal Entities are organizations recognized by law as distinct entities.
Example: SAP LeanIX SARL
  * Team: Teams are groups of users/owners that are typically part of specific Business Units / Countries.
Example: Team Igniteus


After defining your Organizational hierarchy, create corresponding Fact Sheets and add the necessary data. This process includes identifying Business Owners and other stakeholders and gathering and adding all relevant information. To learn more about modeling the Organization Fact Sheet, see the [Organization Modeling Guidelines](https://help.sap.com/docs/leanix/ea/organization-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to model organizations. This includes best practices and applicable use cases, and common antipatterns.").
